pro dbxput,val,entry,idltype,sbyte,nbytes
;+
; Project     :	SOHO - CDS
;
; Name        :	
;	DBXPUT
; Purpose     :	
;	Routine to replace value of an item in a data base entry
; Explanation :	
;	Routine to replace value of an item in a data base entry
; Use         :	
;	dbxput, val, entry, idltype, sbyte, nbytes
; Inputs      :	
;	val - value(s) to be placed into entry, string values might be
;		truncated to fit number of allowed bytes in item
;	entry - entry or entries (allow multiple entries) to be updated, 
;	It is the caller's responsibility to have the required values
;	idltype - idl data type for item
;	sbyte - starting byte in record
;	nbytes - total number of bytes in value added
;
; Opt. Inputs :	None.
;
; Outputs     :	
;	entry - (updated)
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	
;	This routine assumes that the calling procedure or user
;	knows what he or she is doing.  No validity checks are made
;
; Side effects:	None.
;
; Category    :	Utilities, Database.
;
; Prev. Hist. :	
;	version 1, D. Lindler   Aug, 1986
;	converted to IDL Version 2.  M. Greason, STX, June 1990.
;
; Written     :	D. Lindler, GSFC/HRS, August 1986
;
; Modified    :	Version 1, William Thompson, GSFC, 28 March 1994
;			Incorporated into CDS library
;		Version 2, W. Landsman, GSFC/UIT, 28 August 1995
;			Work with multiple element string items
;		Version 3, Really work with multiple element string items   
;			R. Bergman/W. Landsman  July 1996
;		Version 4, R. Schwartz, GSFC/SDAC, 23 August 1996
;			Work with multiple entries
;		Version 5, W. Landsman, May 1997
;			Use /overwrite with REFORM()
;
; Version     :	Version 5, May 1997
;-
;
;-------------------------------------------------------
;
nentry = n_elements(entry(0,*))
case idltype of		;case of data type

   7: begin			;string
	numvals = N_elements(val)                   ;Number of input values
	nbyte = nbytes/numvals                      ;Number of bytes/value
	val = strmid(val,0,nbyte)                   ;Truncate string
	temp = replicate( 32b, nbyte, numvals, nentry)	    ;Array of blanks
	for i = 0, numvals-1 do temp(0,i,0) = byte(val(i,*))     ;Fill with values
	entry(sbyte:sbyte+nbytes-1,*) = reform(temp,nbytes,nentry, /over)  
      end
   1: entry(sbyte:sbyte+nbytes-1,*)=val
   else: entry(sbyte:sbyte+nbytes-1,*) = byte(val,0,nbytes,nentry)

endcase
return
end
