	PRO PLOT_HISTO,ARRAY,STEPS,HISTO,TITLE=TITLE,XTITLE=XTITLE,	$
		YTITLE=YTITLE,XTYPE=XTYPE,YTYPE=YTYPE,DELTA=DELTA,	$
		BCOLOR=BCOLOR,XRANGE=XRANGE,YRANGE=YRANGE
;+
; Project     :	SOHO - CDS
;
; Name        :	PLOT_HISTO
;
; Purpose     :	Plots a histogram from the variable ARRAY.
;
; Category    :	Class3, Graphics
;
; Explanation :	Plots a histogram from the variable ARRAY.  Calls FORM_HISTO to
;		decide what the coarseness of the histogram should be.  Then
;		PLOTBAR is called to plot the histogram.
;
; Syntax      :	PLOT_HISTO, ARRAY  [, STEPS, HISTO ]
;
; Examples    :	
;
; Inputs      :	ARRAY	= Array to plot histogram of.
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	STEPS	= Values at which histogram is taken.  Each value
;			  represents histogram between STEP(I) and STEP(I+1).
;		HISTO	= Histogram values.
;
; Keywords    :	DELTA	= Distance between histogram steps.  If not passed,
;			  then FORM_HISTO chooses a suitable value.
;		TITLE	= Main plot title, default is !P.TITLE.
;		XTITLE	= X axis title, default is !X.TITLE.
;		YTITLE	= Y axis title, default is !Y.TITLE.
;		XTYPE	= If set, then X axis is logarithmic.
;		YTYPE	= If set, then Y axis is logarithmic.
;		BCOLOR	= Color to use instead of !BCOLOR for bar interiors.
;		XRANGE	= Range of data values in the X direction.
;		YRANGE	= Range of data values in the Y direction.
;
; Calls       :	FORM_HISTO, PLOTBAR
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Prev. Hist. :	
;	William Thompson	Applied Research Corporation
;	September, 1987		8201 Corporate Drive
;				Landover, MD  20785
;
;	William Thompson, December 1991, added keywords XTYPE and YTYPE.
;	William Thompson, May 1992, added keywords XRANGE and YRANGE.
;
; History     :	Version 1, 22-Jan-1996, William Thompson, GSFC
;			Incorporated into CDS library
;
; Contact     :	WTHOMPSON
;-
;
	ON_ERROR,2
;
;  Check the input parameters.
;
	IF N_PARAMS(0) EQ 0 THEN MESSAGE,	$
		'Syntax:  PLOT_HISTO, ARRAY  [, STEPS, HISTO ]'
	IF N_ELEMENTS(ARRAY) LE 2 THEN MESSAGE,	$
		' Not enough points to form histogram.'
;
;  Check to see if a histogram is warranted.
;
	BANG_C = !C
	A_MAX = 1.*MAX(ARRAY)
	A_MIN = 1.*MIN(ARRAY)
	!C = BANG_C
	IF A_MAX EQ A_MIN THEN MESSAGE,		$
		'No histogram generated--all array elements equal to ' + $
			STRING(A_MAX)
	IF (A_MAX - A_MIN) LT (1E-4 * ABS(A_MIN)) THEN MESSAGE,	$
		'No histogram generated--data range ' + STRING(A_MIN) + $
			' to ' + STRING(A_MAX) + ' too narrow.'
;
;  Call FORM_HISTO to form the histogram, and PLOTBAR to plot it.
;
	FORM_HISTO,ARRAY,S,HISTO,DELTA=DELTA
	IF N_PARAMS(0) GT 2 THEN STEPS = S
	PLOTBAR,S,HISTO,TITLE=TITLE,XTITLE=XTITLE,YTITLE=YTITLE,XTYPE=XTYPE, $
		YTYPE=YTYPE,BCOLOR=BCOLOR,XRANGE=XRANGE,YRANGE=YRANGE
;
	RETURN
	END
