;+
; Project     : SOHO - CDS     
;                   
; Name        : SMART_WINDOW
;               
; Purpose     : a smarter way to set/restore plot window parameters
;               
; Category    : utility
;               
; Explanation : 
;               
; Syntax      : IDL> smart_window,window
;    
; Examples    : 
;
; Inputs      : WINDOW = window ID number to set to
;               
; Opt. Inputs : None
;               
; Outputs     : None
;
; Opt. Outputs: None
;               
; Keywords    : SET = set current system variables to saved values
;               REMOVE = remove input window from common
;               DRAW = informs that window is a DRAW widget
;               STATUS = 1/0 if success/fail
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: If WINDOW is valid, subsequent plots are directed to it
;               
; History     : Version 1,  24-Jan-1998, Zarro (SAC/GSFC)
;
; Contact     : dzarro@solar.stanford.edu
;-            

pro smart_window,window,set=set,remove=remove,draw=draw,status=status

common smart_window,window_pars
status=1
if ((!d.name ne 'X') and (!d.name ne 'WIN')) then return
status=0
if (not exist(window)) then return

;-- check if window is closed

closed=1
device,wind=ow
where_open=where(ow eq 1,count)
if count gt 0 then begin
 ok=where(window eq where_open,ocount)
 closed=(ocount eq 0) 
endif

;-- check if window parameters are saved

saved=0
if datatype(window_pars) eq 'STC' then begin
 ok=where(window eq window_pars.window,count)
 saved=(count eq 1)
endif

if saved and (closed or keyword_set(remove)) then begin
 keep=where(window ne window_pars.window,count)
 if count eq 0 then delvarx,window_pars else window_pars=window_pars(keep)
 saved=0 
endif
if closed then return

if saved then begin
 if keyword_set(set) then begin
  window_pars(ok).x=!x
  window_pars(ok).y=!y
  window_pars(ok).p=!p
 endif else begin
  !x=window_pars(ok).x
  !y=window_pars(ok).y
  !p=window_pars(ok).p
 endelse
endif else begin
 new_par={window:window,x:!x,y:!y,p:!p}
 window_pars=merge_struct(window_pars,new_par)
endelse

if !d.name eq 'X' then begin
 wset,window
 if (1-keyword_set(draw)) then wshow,window
endif
status=1

return & end
