pro mreadfits_fixup, index, data, loud=loud
;+
;   Name: mreadfits_fixup
;
;   Purpose: adjust some standard fields after mreadfits rebinning
;
;   Input Parameters:
;      index (input/output) - structure array (see mreadfits.pro)
;      data  - corresponding data array (post-rebinning)
;
;   Output Parameters:
;      index - fields adjusted for previous rebinning
;     
;   Calling Sequence:
;      mreadfits_fixup, index, data [,/loud]
;      (by the time you read this, it may be called WITHIN mreadfits)
;  
;   History:
;      4-Jun-1997 - S.L.Freeland
;      5-Jun-1997 - S.L.Freeland - fix an 'off-by-1' error
;     
;-
if n_params() ne 2 then begin
   prstr,strjustify('IDL> mreadfits_fixup, index, data',/box)
   return
endif

xn=float(gt_tagval(index,/naxis1))
yn=float(gt_tagval(index,/naxis2))
sdata=float(size(data))
fx=xn/sdata(1) & fy=yn/sdata(2)
ss=where(fx ne 1 or fy ne 1,ncnt)

; list of tags which are adjusted - add to list as required
tag_adjust=str2arr('cdelt1,cdelt2,solar_r,crpix1,crpix2')
nonemissing=(where(tag_index(index,tag_adjust) eq -1,mcnt))(0) eq -1

; dont adjust unless required - and ONLY if proper tags found
if (ncnt gt 0)  and nonemissing then begin
   message,/info,"applying temporary mreadits parameter fixup..."
   index.cdelt1=(fx)*index.cdelt1
   index.cdelt2=(fy)*index.cdelt2
   index.crpix1  = ( (sdata(1)/float(index.naxis1)) * index.crpix1 )
   index.crpix2  = ( (sdata(2)/float(index.naxis2)) * index.crpix2 )
   index.solar_r = ( (sdata(2)/float(index.naxis2)) * index.solar_r )
   index.naxis1=sdata(1)
   index.naxis2=sdata(2)
endif 

return
end
