;+
; Project     : SDAC
;                   
; Name        : CUM_SUM 
;               
; Purpose     : This function returns the cumulative sum along
;		the first index of an array.
;               
; Category    : UTIL, MATH
;               
; Explanation : A loop is used to sum over each index in a row cumulatively.
;               
; Use         : Result = CUM_SUM( Array )
;    
; Inputs      : Array - an array of up to 8 dimensions.
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns an array of the same dimensions.
;
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls	      :
;
; Common      : None
;               
; Restrictions: 
;               
; Side effects: None.
;               
; Prev. Hist  : written, richard.schwartz@gsfc.nasa.gov, 24-sep-1991
;
; Modified    : 
;
;-            
;==============================================================================
function cum_sum, array

sa  = size(array)
nn  = sa(1:sa(0))

out = reform( array, nn(0), sa(sa(0)+2)/nn(0))

for i=1,nn(0)-1 do out(i,*) = out(i,*)+out(i-1,*)


return, reform( out, nn)
end
