;+
; Name: edge_products
;
; Purpose: From a vector of contiguous channel boundaries return the
;	commonly used quantities for plotting and scaling.
;
; Category:
;	GEN, SPECTRA
;
; Input: Edges -if 1d, contiguous channel boundaries, n+1 values for n channels
;               if 2d, 2xn, [lo(i),hi(i)], etc., assumed contiguous for
;		calculating edges_1
;
; Output:
;	Mean - arithmetic mean of boundaries
;       Gmean - geometric mean
;	width - absolute difference between upper and lower edges
;	edges_2 - 2xn array of edges [lo(i), hi(i)], etc.
;       edges_1 - array of n+1 edges of n contiguous channels
;
; Mod. History:
; ras, 21-oct-93
;-
pro edge_products, edges, mean=mean, gmean=gmean, width=width, $
	edges_2=edges_2, edges_1=edges_1

dims = size( edges )

if dims(0) eq 2 and dims(1) eq 2 then begin
	n = dims(2)
	edges_2 = edges
	edges_1 = [(edges_2(0,*))(*), edges_2(1,n-1)]
endif else begin
	n = n_elements(edges)-1
	edges_2 = transpose( [ [edges(0:n-1)],[edges(1:*)]])
	edges_1 = edges
endelse

mean = total( edges_2,1 )/2.
gmean = ( ((edges_2(0,*)*edges_2(1,*))>0.0)^0.5 )(*)

width = abs(( edges_2(1,*)-edges_2(0,*) )(*))

end
