;+
; PROJECT:
;       SDAC
;
; NAME: 
;	INTERP2INTEG
;
; PURPOSE:
;	This function integrates over the limits on the interpolated array.
;
; CATEGORY:
;	GEN, MATH, UTILITY, NUMERICAL
;
; CALLING SEQUENCE:
;	Integral = INTERP2INTEG( Xlims, Xdata, Ydata)
;
; CALLS:
;	INTERPOL, INT_TABULATED
;
; INPUTS:
;       Xlims - The limits to integrate over. 
;	Xdata, Ydata - Define the tabulated function to integrate over.
;
; OPTIONAL INPUTS:
;	none
;
; OUTPUTS:
;       none explicit, only through commons;
;
; OPTIONAL OUTPUTS:
;	none
;
; KEYWORDS:
;	none
; COMMON BLOCKS:
;	none
;
; SIDE EFFECTS:
;	none
;
; RESTRICTIONS:
;	Complex data types not permitted and not checked.
;	none
;
; PROCEDURE:
;	The data are interpolated into the interval defined by Xlims and then integrated.
;
; MODIFICATION HISTORY:
;	RAS, 2-apr-1996
;	Version 2, richard.schwartz@gsfc.nasa.gov, 7-sep-1997, more documentation
;-
function INTERP2INTEG, Xlims, Xdata, Ydata

on_error,2			;Return to caller

wint = where(xdata ge min(xlims) and xdata le max(xlims), nint)

if nint ge 1 then xtab = [xlims, xdata(wint)] else xtab=xlims

xtab = xtab( uniq( xtab, sort(xtab)))

ytab = interpol( ydata, xdata, xtab)

return, int_tabulated( xtab, ytab)
end

