pro fits_disp_month, infil_arr, smin, smax, gif=gif, dir=dir, filter=filter, char_factor=char_factor
;
;+
;NAME:
;	fits_disp_month
;PURPOSE:
;	To display a single image per day for a single month
;CALLING SEQUENCE:
;	fits_disp_month, files, -50, 50
;	fits_disp_month, file_list('/data14/mdi_summary/daily/maglc', 'smdi_maglc_fd_199611*')
;METHOD:
;	The date of the first image defines which month is to be displayed
;	"DATEOBS" fits keyword must be in the header.
;	If smin/smax are not passed, then the first image defines the
;	image scaling min and max
;HISTORY:
;	Written 27-Nov-96 by M.Morrison (taking SXT disp_month.pro)
;	19-May-97 (MDM) - Added writing boarder lines (because of MDI HR)
;-
;
if (infil_arr(0) eq '') then return
;
nfil = n_elements(infil_arr)
img = rfits(infil_arr(0), h=h)
if (n_elements(smin) eq 0) then smin = min(img)
if (n_elements(smax) eq 0) then smax = max(img)
;
dattim = sxpar(h, 'dateobs')
month = dattim
tarr = anytim2ex(month)
tarr(0:4) = 0
;
if (n_elements(disp_factor) eq 0) then disp_factor = 1.	;use disp_factor = 1.29 for ramtek
if (n_elements(char_factor) eq 0) then char_factor = 1.	;use char_factor = 0.75 for ramtek
nx = 7
ny = 6
siz = 128
win_xsiz = fix(nx*siz*disp_factor+.5)
win_ysiz = fix((ny*siz+25)*disp_factor)
;
	    tarr(4) = 1
	    dummy = anytim2ints(tarr)
	    day1 = dummy.day
	    dow = ex2dow(anytim2ex(month))

	    tv2, win_xsiz, win_ysiz, /already, /init
	    erase

	    ref_dow = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday']
	    for i=0,6 do xyouts, siz*i*disp_factor, ny*siz*disp_factor+5, ref_dow(i), /device, charsize=(disp_factor+.4)*char_factor

	    for ifil=0,nfil-1 do begin
	        infil = infil_arr(ifil)
		data = rfits(infil, h=h)
		dattim = sxpar(h, 'dateobs')
		ii = (gt_day(dattim) - day1) + dow
		x0 = (ii mod nx)*siz*disp_factor
		y0 = (ny-1 - ii/nx)*siz*disp_factor
		data = congrid(data, siz*disp_factor, siz*disp_factor, interp=0)
		data = bytscl(data, smin, smax)
		data(0,*) = 0
		data(*, n_elements(data(0,*))-1) = 0
		tv, data, x0, y0
		xyouts, x0, y0, fmt_tim(dattim), /device, charsize=disp_factor*char_factor
	    end

	    month_str = strmid(gt_day(dattim, /str, /longmonth), 3, 100)
	    xyouts, win_xsiz*.5, 50, month_str, charsize = 6*disp_factor*char_factor, /dev, charthick=3
;
if (keyword_set(gif) and (!d.name eq 'Z')) then zbuff2file, gif
;
end
