pro plot_hist, data, x, h, bin=bin, xrange=xrange, yrange=yrange, $
   tit=tit, log=log, noerase=noerase, linestyle=linestyle, $
   charsize=charsize, xtitle=xtitle, oplot=oplot
;
;+
;NAME:
;	plot_hist
;PURPOSE:
;	To plot a histogram with a properly labeled X axis.
;SAMPLE CALLING SEQUENCE:
;	plot_hist, img
;	plot_hist, img, x, h
;	plot_hist, img, bin=0.1
;	plot_hist, img, xrange=xrange, yrange=yrange, tit=tit
;INPUT:
;	data	- The data to perform the historam on
;OUTPUT:
;	x	- The x axis for the plotting
;	h	- The histogram
;OPTIONAL KEYWORD INPUTS:
;	bin	- The bin size to use (default is 1)
;	xrange	- The x plotting range
;	yrange	- The y plotting range
;	tit	- The title
;	log	- If set, then plot the y axis in log form
;HISTORY:
;	Written Apr-95 by M.Morrison
;	18-May-95 (MDM) - Added /LOG switch
;			- Plot such that the minimum occurance is 0.1
;	 7-Jul-95 (MDM) - Fixed the plot so that min occurance is 0.1
;	27-Nov-95 (LWA) - Added noerase, linestyle, charsize  keywords.
;	 8-Nov-96 (MDM) - Merged 27-Nov-95 changes with the ones below:
;		17-May-96 (MDM) - Added xtitle
;		11-Sep-96 (MDM) - Added ROUND when creating "data0"
;	 8-Nov-96 (MDM) - Added "oplot" option
;-
;
if (n_elements(bin) eq 0) then bin = 1
;
data0 = round(data/bin)

h = histogram(data0)
n = n_elements(h)
amin = min(data0)
x = findgen(n)*bin + long(amin)*bin
;
if NOT keyword_set(charsize) then charsize=0 else charsize=charsize
if NOT keyword_set(linestyle) then linestyle=0 else linestyle=linestyle
if (n_elements(xrange) eq 0) then xrange = [min(x), max(x)]
if (n_elements(yrange) eq 0) then yrange = [min(h)>0.1, max(h)]
if (n_elements(tit) eq 0) then tit = ''
if (n_elements(xtitle) eq 0) then xtitle = 'Value'
;
if (keyword_set(oplot)) then begin
    oplot, x, h, psym=10, linestyle=linestyle
end else begin
    plot, x, h, psym=10, ytit='# of Occurrences', xtit=xtitle, $
	xrange=xrange, yrange=yrange, tit=tit, ytype=keyword_set(log), $
	noerase=noerase, linestyle=linestyle, charsize=charsize
end
;
end
