function track_proc, name0, proc0, proc1, qdebug=qdebug, kill=kill, mat=mat, result=result, term0=term0
;+
;NAME:
;	track_proc
;PURPOSE:
;	To find all processes for a given process name and user.  Optionally
;	kill the process
;SAMPLE CALLING SEQUENCE:
;	pids = track_proc('mdi', 'mdi_sci')
;	pids = track_proc('mdi', 'mdi_sci', 'bin.sgi/idl')
;	pids = track_proc('mdi', 'mdi_sci', term0='?', /kill)
;RESTRICTION:
;	Only runs on SGI
;HISTORY:
;	Written 30-May-96 by M.Morrison
;	 8-Aug-96 (MDM) - Added TERM0 option
;-
;
qdebug = 1
;
spawn, ['ps', '-edalf'], result, /noshell
result = result(1:*)		;drop title line
mat = strtrim(str2cols(result),2)
;
name = reform(mat(2,*))
pid  = long(reform(mat(3,*)))
ppid = long(reform(mat(4,*)))
proc = reform(mat(15,*))
term = reform(mat(13,*))
;
p1 = strpos(proc, proc0)
if (keyword_set(term0)) then ss = where( (name eq name0) and (p1 ne -1) and (ppid gt 128) and (term eq term0), nss) $
			else ss = where( (name eq name0) and (p1 ne -1) and (ppid gt 128), nss)
if (nss eq 0) then begin
    print, 'Cannot find process: ' + proc0 + ' with user: ' + name0
    return, -1
end
;
print, '---- Main processes found:'
prstr, result(ss), /nomore
;
out_pids = pid(ss)
out_ppids = ppid(ss)
out = -1
for i=0,n_elements(out_pids)-1 do begin
    cpid = out_pids(i)
    cppid = out_ppids(i)
    ;
    while (cpid ne -1) do begin
	out = [out, cpid]
	;ss = where((pid eq cppid) and (name eq name0), nss)
	if (keyword_set(term0)) then ss = where((pid eq cppid) and (name eq name0) and (term eq term0), nss) $
				else ss = where((pid eq cppid) and (name eq name0), nss)
	if (nss eq 0) then begin
	    cpid = -1
	end else begin
	    cpid = pid(ss(0))
	    cppid = ppid(ss(0))
	end
    end
end
out = out(1:*)
;
if (keyword_set(qdebug)) then begin
    ss = where_arr(pid, out)
    print, '---- Related processes found:'
    prstr, result(ss)
end
;
if (keyword_set(proc1)) then begin	;find just the task with process proc1
    ss = where_arr(pid, out)
    p1 = strpos(proc(ss), proc1)
    ss2 = where(p1 ne -1, nss)
    if (nss eq 0) then begin
	print, 'Cannot find process in sub-list with name: ' + proc1
	return, -1
    end
    out = pid(ss(ss2))
    ;
    if (keyword_set(qdebug)) then begin
        ss = where_arr(pid, out)
        print, '---- Related sub-processes found:'
        prstr, result(ss)
    end
end
;
if (keyword_set(kill)) then begin
    cmd = ['kill', '-9', strtrim(out,2)]
    print, 'Issuing cmd: ' + arr2str(cmd, delim=' ')
    spawn, cmd, /noshell
end
;
return, out
end