;+
; Project     : SOHO - CDS     
;                   
; Name        : CSCALE
;               
; Purpose     : my own color scale routine
;               
; Category    : display
;               
; Explanation : 
;               
; Syntax      : IDL> a=cscale(b)
;    
; Examples    : 
;
; Inputs      : B = input array to scale
;               
; Opt. Inputs : 
;               
; Outputs     : None
;
; Opt. Outputs: None
;               
; Keywords    :
;               TOP = top color index to scale to [def=!d.table_size-1]
;               BOTTOM = bottom color index to scale to [def=0]
;               MIN = min data to scale [def=min(b)]
;               MAX = max data to scale [def=max(b)]
;               MISSING = data to exclude [i.e., set to dmin]
;               NO_COPY = destroy input array
;               REVERSE = reverse color scale min->max
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None.
;               
; History     : Version 1,  17-Jan-1998,  D M Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-            


function cscale,array,top=top,bottom=bottom,min=amin,max=amax,missing=missing,$
                 reverse=reverse,no_copy=no_copy

;-- defaults

if not exist(array) then return,0
cmax=!d.table_size-1
if not exist(top) then ctop=cmax else ctop=top < cmax
if not exist(bottom) then cbot=0. else cbot=bottom > 0.
if not exist(amin) then dmin=min(array) else dmin=amin
if not exist(amax) then dmax=max(array) else dmax=amax
if keyword_set(reverse) then begin
 temp=ctop & ctop=cbot & cbot=temp
endif

if exist(missing) then begin
 nok=where(array eq missing,count)
 if count gt 0 then array(missing)=dmin
endif

ctop=float(ctop)
cbot=float(cbot)
dmax=float(dmax)
dmin=float(dmin)

if dmin eq dmax then return,array

slope=(ctop-cbot)/(dmax-dmin)
off=ctop-slope*dmax

if keyword_set(no_copy) then carray=temporary(array) else carray=array
carray= dmin > temporary(carray) < dmax
return,byte(nint(slope*temporary(carray)+off))
end


