;---------------------------------------------------------------------------
; Document name: valid_gif.pro
; Created by:    Liyun Wang, GSFC/ARC, November 1, 1995
;
; Last Modified: Thu Nov  2 11:34:49 1995 (lwang@achilles.nascom.nasa.gov)
;---------------------------------------------------------------------------
;
FUNCTION valid_gif, filename, error=error
;+
; PROJECT:
;       SOHO - CDS/SUMER
;
; NAME:
;       VALID_GIF()
;
; PURPOSE:
;       To detect if the given file is in GIF format
;
; CATEGORY:
;       Utility
;
; EXPLANATION:
;
; SYNTAX:
;       Result = valid_gif(filename)
;
; INPUTS:
;       FILENAME - Name of the file to be detected
;
; OPTIONAL INPUTS:
;       None.
;
; OUTPUTS:
;       RESULT   - 1/0 indicating whether the given file is or is not
;                  a GIF file
;
; OPTIONAL OUTPUTS:
;       None.
;
; KEYWORDS:
;       ERROR - A named variable containing any error message. If no
;               error occurs, a null string is returned.
;
; COMMON:
;       None.
;
; RESTRICTIONS:
;       None.
;
; SIDE EFFECTS:
;       None.
;
; HISTORY:
;       Version 1, November 1, 1995, Liyun Wang, GSFC/ARC. Written
;
; CONTACT:
;       Liyun Wang, GSFC/ARC (Liyun.Wang.1@gsfc.nasa.gov)
;-
;
   ON_ERROR, 2
   error = ''
   IF datatype(filename) NE 'STR' THEN BEGIN
      error = 'Syntax: a = valid_gif(filename)'
      MESSAGE, error, /cont
      RETURN, 0
   ENDIF

   h = {magic:BYTARR(6), width_lo:0b, width_hi:0b, $
        height_lo:0b, height_hi:0b, $
        screen_info:0b, background:0b, reserved:0b }

   IF NOT file_exist(filename) THEN BEGIN
      error = 'File "'+STRTRIM(filename,2)+'" does not exist!'
      MESSAGE, error, /cont
      RETURN, 0
   ENDIF
   
   on_ioerror,bad
   OPENR, unit, filename, /GET_LUN, /block,error=err
   if err ne 0 then begin
    error=!err_string
    print,error
    goto,bad
   endif

   
   READU, unit, h
   FREE_LUN, unit

   gif = STRING(h.magic(0:2))
   d1 = STRING(h.magic(3))
   d2 = STRING(h.magic(4))
   a = STRING(h.magic(5))

   a_is_ok = (a GE 'a' AND a LE 'z') OR (a GE 'A' AND a LE 'Z')

   IF gif NE 'GIF' OR d1 LT '0' OR d1 GT '9' OR    $
      d2 LT '0' OR d2 GT '9' OR a_is_ok(0) EQ 0 THEN RETURN, 0 ELSE RETURN, 1

bad: return,0
END

;---------------------------------------------------------------------------
; End of 'valid_gif.pro'.
;---------------------------------------------------------------------------
