;+
; Project     :	SDAC
;
; Name        :	X2GIF
;
; Purpose     :	read and write X window to GIF file
;
; Explanation :	Uses TVRD to grab window
;
; Use         :	X2GIF,FILE
;              
; Inputs      :	FILE = GIF file name
;
; Opt. Inputs : R, G, B = color table values
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	
;               WINDOW = index of window to be plotted
;               XSIZE, YSIZE = window size to select [def = whole window]
;               TITLE = title for GIF file
;               XPOS, YPOS = position of title
;               PSIZE = extra keywords for xyouts
;               RESIZE = [nx,ny] = dimensions to resize GIF image to
;               
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Graphics
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (ARC)
;
; Version     :	Version 1.0, 1 July 1994
;-
 
pro x2gif,file,r,g,b,window=window,xsize=xsize,ysize=ysize,title=title,$
               _extra=psize,xpos=xpos,ypos=ypos,resize=resize,err=err

err=''

if datatype(file) ne 'STR' then begin
 file='idl.gif'
 message,'GIF file saved in '+file,/cont
endif

break_file,file,dsk,dir,name,ext
out_dir=trim(dsk+dir)
cd,curr=curr
if out_dir eq '' then out_dir=curr
ok=test_open(out_dir,/write)
if not ok then begin
 err='Cannot write GIF file to '+out_dir
 message,err,/cont
 return
endif

if ((n_elements(window) eq 0) and (!d.window eq -1)) or (!d.name ne 'X') then begin
 err='NO WINDOW ACTIVE'
 message,err,/cont
 return
endif


if n_elements(window) ne 0 then begin
 if window gt -1 then wset,window
endif
 
;-- read window

if n_elements(xsize) eq 0 then xsize=!d.x_size
if n_elements(ysize) eq 0 then ysize=!d.y_size

;-- write title

if datatype(title) eq 'STR' then begin
 if n_elements(xpos) eq 0 then xpos=.1
 if n_elements(ypos) eq 0 then ypos=.9
 xyouts,xpos,ypos,title,_extra=psize,norm=1,size=1.5,charthick=1.5,font=-1
endif

dev_save=!d.name
select_windows
a=tvrd(0,0,xsize,ysize)
if n_elements(resize) eq 2 then begin
 if (resize(0) ne xsize) or (resize(1) ne ysize) then $
  a=congrid(a,resize(0),resize(1))
endif

;-- load user-supplied colors, else check what is in COMMON COLORS

cload=0
if n_elements(r)*n_elements(g)*n_elements(b) ne 0 then cload=1

if cload eq 0 then begin
 tvlct,r,g,b,/get
 cload=1
endif

if cload then write_gif,file,a,r,g,b else write_gif,file,a

set_plot,dev_save


return & end
