pro write_genxcat, structures, topdir=topdir, weeksub=weeksub, $
		   prefix=prefix, text=text, catname=catname
;
;+  Name: write_genxcat
;
;   Purpose: write one 'catlog' in genx format (read by read_genxcat)
;
;   Input Parameters:
;      structures - structures to write to catalog
;  
;   Keyword Parameters:
;      topdir  -  optional parent diretory for output (catalog) files
;      text - optional string or string array text descriptor to include
;      weeksub - if set, prepend weekly subdirectory to output path
;      prefix  - if supplied, optional prefix (prepend to first struct. GMT)
;      catname - optional fully defined name for output (.genx added)  
;  
;   Restrictions:
;     input structures must include an SSW standard time field 
;
;   History:
;       10-March-1998 - S.L.Freeland
;-
case 1 of
   required_tags(structures,'day,time'): fname=time2file(structures(0))
   required_tags(structures,'mjd,time'): fname=time2file(structures(0))
   required_tags(structures,'date_obs'): $
         fname=time2file( anytim(gt_tagval(structures(0),/date_obs) ,/ints))
      else: begin
         box_message,'Required tags ' + arr2str([missing1,missing2]) +' are missing'
         return
     endcase
endcase

if data_chk(catname,/string) then fname=catname(0)  ; override with user supplied

itext='Written by <write_genxcat> at ' + systime()
case 1 of
    data_chk(text,/string): itext=[text,itext]
    else:
endcase

if not data_chk(topdir,/string) then topdir=curdir()
if keyword_set(weeksub) then $
    topdir=concat_dir(topdir,'week'+anytim2weekinfo(structures(0),/first))

if not data_chk(prefix,/string) then prefix=''
if not data_chk(catname,/string) then catname=concat_dir(topdir,prefix+fname)
savegen, structures, file=catname, text=itext               ; write catalog

return
end
