;+
; Project     : SOHO-CDS
;
; Name        : DIFF_MAP
;
; Purpose     : Difference two maps
;
; Category    : imaging
;
; Explanation : 
;
; Syntax      : diff=diff_map(map1,map2)
;
; Examples    :
;
; Inputs      : MAP1,MAP2 = image maps
;
; Opt. Inputs : None
;
; Outputs     : DIFF = MAP2-MAP1
;
; Opt. Outputs: None
;
; Keywords    : RUNNING = if MAP1 is an array, then produce
;               a running difference (map(i)=map(i+1)-map(i), etc)
;               ROTATE  = rotate maps to common time before rotating
;
; Common      : None
;
; Restrictions: RUNNING is not yet implemented
;
; Side effects: None
;
; History     : Written 1 April 1998, D. Zarro, SAC/GSFC
;
; Contact     : dzarro@solar.stanford.edu
;-


function diff_map,map1,map2,rotate=rotate

if (not valid_map(map1)) or (not valid_map(map2)) then begin
 pr_syntax,'map=diff_map(map1,map2,[rotate=rotate])
 return,-1
endif
 
if keyword_set(rotate) then dmap=drot_map(map1,ref=map2) else $
 dmap=map1

diff=map2.data-dmap.data
dmap=map2
dmap.data=diff
add_prop,dmap,difference=map2.time+' - '+map1.time
 
return,dmap
end

