;+
; Project     : SOHO-CDS
;
; Name        : MERGE_MAP
;
; Purpose     : merge to image maps
;
; Category    : imaging
;
; Explanation : 
;
; Syntax      : imap=merge_map(map1,map2)
;
; Examples    :
;
; Inputs      : MAP1, MAP2 = two image maps to merge
;
; Opt. Inputs : None
;
; Outputs     : IMAP = merged map
;
; Opt. Outputs: None
;
; Keywords    : ERR = error strings
;               SPACE = [dx,dy] = grid spacing
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Written 13 January 1998, D. Zarro, SAC/GSFC
;
; Contact     : dzarro@solar.stanford.edu
;-

function merge_map,map1,map2,err=err,_extra=extra,space=space

err=''
on_error,1

if (not valid_map(map1)) or (not valid_map(map2))  then begin
 pr_syntax,'map=merge_map(map1,map2)'
 return,-1
endif

;-- pull out data and (x,y) coordinates
;-- use pixel scale of first image as reference [unless user specifies SPACE]

unpack_map,map1,data1,xp1,yp1,dx=dx,dy=dy
unpack_map,map2,data2,xp2,yp2

if n_elements(space) ne 2 then gspace=[dx,dy] else gspace=space

grid_xy,[xp1(*),xp2(*)],[yp1(*),yp2(*)],gx,gy,space=gspace

;-- create output map

sz=size(gx)
dprint,'%MERGE_MAP: new output image dimensions: ',sz(1),sz(2)
dprint,'%MERGE_MAP: output image spacings: ',gspace(0),gspace(1)
temp=make_array(sz(1),sz(2),/float)
imap=rep_tag_value(map1,temp,'data')
imap=repack_map(imap,gx,gy)

;-- now interpolate input maps onto new output map

imap1=inter_map(map1,imap)
imap2=inter_map(map2,imap1)

;imap.data=(imap1.data+imap2.data)/2.
imap.data=imap2.data

return,imap & end


