;+
; Project     : SOHO-CDS
;
; Name        : MK_CDS_SMAP
;
; Purpose     : Make an image map from a CDS QL structure in which
;               slit spectrogram mode is used
;
; Category    : imaging
;
; Explanation : 
;
; Syntax      : map=mk_cds_smap(aa)
;
; Examples    :
;
; Inputs      : aa = CDS quicklook data stucture
;               window = window number
;
; Opt. Inputs : None
;
; Outputs     : MAP = map structure
;
; Opt. Outputs: None
;
; Keywords    : None
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Written 22 June 1997, D. Zarro, ARC/GSFC
;
; Contact     : dzarro@solar.stanford.edu
;-

  function mk_cds_smap,aa,window,_extra=extra,err=err

  err=''
  qlmgr,aa,valid
  if not valid then begin
   err='Invalid QL structure'
   return,-1
  endif
  dim=gt_dimension(aa)
  if dim.ssolar_x gt 1 then begin
   err='Non-singular X-dimension. Use MK_CDS_IMAP'
   message,err
   return,-1
  endif

  if not exist(window) then window=gt_cds_window(aa)
  if window(0) lt 0 then begin
   err='Aborted'
   return,-1
  endif

  map=-1
  nw=n_elements(window)
  time=gt_start(aa,/vms)
  dur=float(gt_duration(aa,/sec))
  for i=0,nw-1 do begin
   temp=gt_windata(aa,window(i),err=err) > 0.
   if err eq '' then begin

;-- get images, pointing, & times

    temp=reform(temporary(temp))
    gt_solar_xy,aa,window(i),xp,yp
    xp=reform(temporary(xp))
    yp=reform(temporary(yp))

;-- make map

    xc=get_img_center(xp,dx=dx)
    yc=get_img_center(yp,dy=dy)

    tmap=make_map(temporary(temp),xc=xc,yc=yc,dx=dx,dy=dy,_extra=extra,$
       time=time,dur=dur,units='arcsecs',$
       id=cds_wave_label((aa.detdesc.label)(window(i))),soho=1)
    map=merge_struct(map,tmap)
   endif
  endfor

  return,map

  end
