;+
; Project     : SOHO-CDS
;
; Name        : REPACK_MAP
;
; Purpose     : Pack pixel coordinate arrays into image map
;
; Category    : imaging
;
; Explanation : 
;
; Syntax      : rmap=repack_map(map,xp,yp)
;
; Examples    :
;
; Inputs      : MAP = map structure
;               XP,YP = 2-d coordinate arrays
;
; Opt. Inputs : None
;
;
; Outputs     : RMAP = repacked map
;
; Opt. Outputs: 
;
; Keywords    : None
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Written 22 Feb 1998, D. Zarro, SAC/GSFC
;
; Contact     : dzarro@solar.stanford.edu
;-

function repack_map,map,xp,yp,err=err

on_error,1
err=''
if not valid_map(map,err=err,old=old) then begin
 message,err,/cont 
 if exist(map) then return,map else return,0
endif

rmap=map
if old then begin
 s1=size(xp)
 s2=size(rmap.xp)
 if (s1(1) eq s2(1)) and (s1(2) eq s2(2)) then begin
  rmap.xp=xp & rmap.yp=yp
 endif else begin
  rmap=rep_tag_value(rmap,xp,'xp')
  rmap=rep_tag_value(rmap,yp,'yp')
 endelse
endif else begin
 rmap.xc=get_img_center(xp,dx=dx)
 rmap.yc=get_img_center(yp,dy=dy)
 rmap.dx=dx
 rmap.dy=dy
endelse

return,rmap & end

