;+
; Project     : SOHO-CDS
;
; Name        : SHIFT_MAP
;
; Purpose     : shift an image map 
;
; Category    : imaging
;
; Explanation : translate a map in x- and y-directions by moving
;               it's centroid
;
; Syntax      : smap=shift_map(map,sx,sy)
;
; Examples    :
;
; Inputs      : MAP = image map structure
;               SX,SY = shift values in x- and y- directions (+W, +N)
;
; Opt. Inputs : None
;
; Outputs     : SMAP = shifted map
;
; Opt. Outputs: None
;
; Keywords    : XC = new X-center (ignored if SX entered)
;               YC = new Y-center (ignored if SY entered)
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Written 12 May 1998, D. Zarro, SAC/GSFC
;
; Contact     : dzarro@solar.stanford.edu
;-

function shift_map,map,sx,sy,err=err,xc=xc,yc=yc

on_error,1
err=''

;-- check inputs 

if not valid_map(map,old=old) or (not exist(sx) and not exist(xc)) then begin
 pr_syntax,'smap=shift_map(map,sx,sy,[xc=xc,yc=yc])'
 if exist(map) then return,map else return,-1
endif

for i=0,n_elements(map)-1 do begin
 err=''
 tmap=map(i)
 unpack_map,tmap,data,xp,yp,xc=pxc,yc=pyc

 xshift=0.
 if exist(sx) then xshift=sx else $
  if exist(xc) then xshift=xc-pxc

 yshift=0.
 if exist(sy) then yshift=sy else $
  if exist(yc) then yshift=yc-pyc

 if (xshift ne 0.) or (yshift ne 0.) then begin
  if old then begin
   xp=temporary(xp)+xshift
   yp=temporary(yp)+yshift
   tmap=repack_map(tmap,xp,yp)
  endif else begin
   tmap.xc=tmap.xc+xshift
   tmap.yc=tmap.yc+yshift
  endelse
 endif

 smap=merge_struct(gmap,tmap)
endfor

return,smap & end

