;+
; Project     : SOHO-CDS
;
; Name        : VALID_MAP
;
; Purpose     : check if input image map is of valid type
;
; Category    : imaging
;
; Explanation : 
;
; Syntax      : valid=valid_map(map)
;
; Examples    :
;
; Inputs      : MAP = image map structure
;
; Opt. Inputs : None
;
; Outputs     : VALID = 1/0 if valid/invalid
;
; Opt. Outputs: None
;
; Keywords    : OLD_FORMAT = 1/0 if using old .xp, .yp format or not
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Written 22 October 1997, D. Zarro, SAC/GSFC
;
; Contact     : dzarro@solar.stanford.edu
;-

function valid_map,map,err=err,old_format=old_format

err='invalid input map'
valid=0b
if datatype(map) ne 'STC' then return,valid

old_format=tag_exist(map,'xp') and tag_exist(map,'yp')

if not old_format then begin
 if not tag_exist(map,'XC') then return,valid
 if not tag_exist(map,'YC') then return,valid
 if not tag_exist(map,'DX') then return,valid
 if not tag_exist(map,'DY') then return,valid
endif else begin
 if not tag_exist(map,'TIME') then return,valid
 if not tag_exist(map,'DATA') then return,valid
endelse

err=''
valid=1b
return,valid & end

