pro ssw_install, qfile=qfile
;+
;   Name: ssw_install
;
;   Purpose: Interface routine to SolarSoft library installation
;
;   History:
;      25-May-1996 - S.L.Freeland (Written)
;       4-Jun-1996 - 
;
;   Method:
;      uses WWW FORM input to define generate a customized C-SHELL 
;      installation script
;-

common ssw_install_blk, ssw_install_txt

if n_elements(ssw_install_txt) eq 0 then $
   ssw_install_txt=rd_tfile('/ssw/gen/bin/ssw_install')

break_file,qfile,ll,pp,ff,ee,vv

top=get_logenv('path_http')
outhtml=concat_dir(top,concat_dir('html_client',ff+'.html'))
outscript=concat_dir(top,concat_dir('text_client',ff+'.csh'))

info=url_decode(qfile=qfile)

sxt_html,/header,outhtml,title='SolarSoft (SSW) Installation'
dat=rd_tfile(outhtml)
ss=where(strpos(dat,'<IMG') ne -1,sscnt)
if sscnt eq 1 then $
   dat(ss)='<center><font size=+3><em>Solar...</em></font>' + dat(ss) + $
     '<font size=+3><em>...Soft</em></font></center>'
file_append,outhtml,str_replace(dat,'SXTSTRIP','SSWSTRIP'),/new

tags=tag_names(info)
inst=wc_where(tags,'SSW_*',cnt)
sswhost=where(tags eq 'SSWHOST',hcnt)

if hcnt eq 0 then $
   sswhost='sohoftp.nascom.nasa.gov' else sswhost=info.(sswhost(0))

sets='SSW_SSW_GEN'			; everybody gets this
if cnt gt 0 then sets=[sets,tags(inst)]
cnt=n_elements(sets)

; add multi-mission GEN areas
mm=strupcase(str2arr('yohkoh,ydb,soho,smm'))	; what they want (request)
mg=strupcase(str2arr('yohkoh,yohkoh,soho,smm'))  ; implied GEN branch

for i=0,n_elements(mm)-1 do begin
   chk=where(strpos(sets,'SSW_'+mm(i)) eq 0,ccnt)			; 
   if ccnt gt 0 then sets=['SSW_'+mg(i)+'_GEN',sets]	; map->implied GEN
endfor

yosets=where(strpos(sets,'YOHKOH') ne -1, ycnt)
if ycnt gt 0 then sets=[sets,'SSW_YOHKOH_YSGEN','SSW_YOHKOH_UCON']	; backward compatible

sets=sets(uniq(sets,sort([sets])))			; no redundanc

order=sort(strmid(sets,4,1))				; sort by 'mission'
sets=sets(order)


sline=string(replicate((byte('#'))(0),60))

case 1 of 
   info.path_ssw eq '': file_append,outhtml,$
	"<p><b>Warning:You did not specify a local path for SSW</b>"
   cnt eq 0: file_append,outhtml,"No Instruments requested"
   else: begin
      missinst=strsplit(sets,'_',tail=miss)
      miss=strsplit(miss,'_',tail=branch)   
      table=transpose([['Mission/Top',miss],['Instrument/Branch',branch]])
      file_append,outhtml, $
         ['Requested installation will include...',strtab2html(table,/row0header)]
;     customize the installation script
      file_append,/new,outscript,['#!/bin/csh -f',sline,$
                          '# created via WWW at ' + systime(), sline]
;     prepend default sets...
      file_append,outscript,'setenv SSW ' + info.path_ssw
      outenv=['ssw_ssw_site']
      outenv=[outenv, strlowcase(sets)]
      ssdb=where(strpos(outenv,'db_') ne -1,dbcnt)
      sssw=where(strpos(outenv,'db_') eq -1,swcnt)
      swsets=''
      dbsets=''
      if swcnt gt 0 then swsets=arr2str(outenv(sssw),' ')
      if dbcnt gt 0 then dbsets=arr2str(outenv(ssdb),' ')
      file_append, outscript, 'setenv ssw_host ' + sswhost
      file_append, outscript, 'setenv ssw_sw_host ' + sswhost
      file_append, outscript, 'setenv ssw_sw_sets "' + swsets + '"'
      file_append, outscript, 'setenv ssw_db_sets "' + dbsets + '"'
      file_append, outscript, [sline,'',ssw_install_txt(1:*)]
      file_append, outhtml, str2html(str_replace(outscript,$
         get_logenv('path_http'),get_logenv('top_http')), $
            link='Your installation script')
   file_append,outhtml, $
      ['<p>Copy this script to a local disk and execute it via:<br>', $
	'<b>% csh -f <em>filename</em></b>']
   endcase
endcase

print,'- ' + outhtml + ' -'
sxt_html,/trailer, outhtml
wait,3
return
end
