pro sswdb_upgrade, relsets, _extra=_extra, site=site, $
                 outdir=outdir, outpackage=outpackage, $
		 nopackage=nopackage,                  $
		 nospawn=nospawn, noexecute=noexecute, $
		 local_sets=local_sets, remote_sets=remote_sets, $
		 debug=debug, spawnit=spawnit, $
                 loud=loud, verbose=verbose, result=result, $
                 user=user, group=group, mirror=mirror, local_mirror=local_mirror
;+
; Name: sswdb_upgrade
;
; Purpose: generate SSW set list, generate packages and spawn mirror job
;
; Keyword Parameters:
;   SITE - if set, include $SSW/site (only on request)
;   XXX  - ex: /eit, /mdi, /sxt, /trace.. update only specified instruments
;                (if none specified , list is derived from $SSW_INSTR)
;   outdir -     local path to keep mirror files (def=$SSW_SITE_MIRROR)
;   outpackage - name of mirror file (def='ssw_upgrade.mirror')
;   no package - if set, do not generate new package 
;   spawnit    - if set, spawn the mirror job
;   nospawn    - if set, do not spawn/execute mirror (ex: just make package) DEFAULT
;   noexecute  - synonym for nospawn
;   remote_sets (output) - list of remote sets/paths (on SSW master)
;   local_sets  (output) - list of local ( relative to $SSW)
;   loud - switch, if set, echo Mirror output 
;   verbose - switch , if set, synonym for /LOUD
;   result (output) - output of mirror command
;   mirror - optional path/name of mirror to run (default = ssw_bin('mirror'))
;           
; Calling Examples:
;
; History:
;    11-Feb-1998 - S.L.Freeland - Starting from ssw_upgrade.pro   
;    5-nov-1997 - S.L.Freeland - make yohkoh/gen imply yohkoh/ucon
;
; Restrictions:
;   for now, all local in terms of local $SSWDB (no split instrument trees)
;   Assume SolarSoft & Perl installed on local machine 
;-
debug=keyword_set(debug)
spawnit=keyword_set(spawnit)               ; 17-Januaray-1997 DEFAULT = /NOSPAWN
loud=keyword_set(loud) or keyword_set(verbose)

if n_elements(group) eq 0 then group=get_group()
if n_elements(user) eq 0 then user=get_user()

sswtop='/sdb'                                        ; host tree top
ssw_host=(get_logenv('ssw_mirror_site'))(0)                ; defult=sohoftp

if ssw_host eq '' then ssw_host='sohoftp.nascom.nasa.gov'  ; default at GSFC

multi_miss=str2arr('yohkoh,soho,smm')             ; multiple instrument missions

; Optionally generate Instrument list via keyword inheritance
if keyword_set(_extra) then begin
   instr=strlowcase(str_replace(tag_names(_extra),'SSW_',''))
endif else instr=   str2arr(get_logenv('SSW_INSTR'),' ')

; ---------- prepare the lists (remote and local SSW pathames) ------------
allinstrx=str2arr(get_logenv('SSW_INSTR_ALL'),' ')
allmiss =strsplit(allinstrx,'/',tail=allinstr)
missions=str2arr(get_logenv('SSW_MISSIONS'),' ')
; ------------------------------------------
; protect against unexpected environmentals (missions ne '')

for i=0,n_elements(missions)-1 do set_logenv,missions(i),'',/quiet

ss=where_arr(allinstr,instr, count)                       ; map local->remote
gensets=['gen']                                           ; implied GEN trees

if count gt 0 then begin
   sss=where(allmiss(ss) eq allinstr(ss),smcnt)           ; mission=instrument?
   if smcnt gt 0 then allinstr(ss(sss))=''                ; null out
   insets=concat_dir(allmiss(ss),allinstr(ss))            ; instruments
endif 
mm=where_arr(multi_miss,allmiss(ss),count)
if count gt 0 then gensets=[gensets,concat_dir(multi_miss(mm),'gen')]     ; implied mission GEN

gensets=gensets(uniq(gensets,sort(gensets)))
allsets=[gensets,insets]  
allsets=allsets(uniq(allsets,sort(allsets)))              ; uniq list

if keyword_set(relsets) then allsets=relsets

;------------------------------------------------------------------------

; define local and remote                           ;ouput and for mirror 
remote_sets=concat_dir(sswtop,allsets)
local_sets =concat_dir('$SSWDB',allsets)
; ----------------- generate mirror package -------------------------

if not keyword_set(nopackage) then begin
   if not keyword_set(outpackage) then outpackage='sswdb_upgrade.mirror' 
   break_file,outpackage,ll,pp,ff,ee,vv    
   case 1 of
      keyword_set(outdir): 
      file_exist(pp): outdir=pp
      file_exist(get_logenv('SSW_SITE_MIRROR')): outdir=get_logenv('SSW_SITE_MIRROR')
      else: outdir=get_logenv('SSW_SITE_SETUP')
   endcase
   pfile=concat_dir(outdir,ff+ee+vv)
   file_delete,pfile, status
   if file_exist(pfile) then begin
      prstr,strjustify(["WARNING: File: " + pfile , $
        "exists and you do not have update priviledge - aborting...", $
        "Remove file or use OUTPACKAGE and OUTDIR keywords to define a", $
        "different mirror file name...","", $
        "   IDL> sswdb_upgrade[,/switches], OUTDIR='pathname',OUTPACK='filename'"],/box)
        return
   endif
   make_mirror,ssw_host,remote_sets,local_sets, $
      comment='sswdb_upgrade_'+ str_replace(remote_sets,'/','_'), $
      mirror_file=pfile,/mode_copy, group=group, user=user, $
      max_delete_file='99%', max_delete_dirs='99%'
endif

; --------------- spawn mirror (do the update) ----------------------
if spawnit then begin
   case 1 of
      data_chk(mirror,/string):                     ; user passed
      keyword_set(local_mirror): mirror='mirror'    ; local alias
      else: mirror=$
       concat_dir(concat_dir(concat_dir('$SSW','gen'),'mirror'),'mirror')
   endcase
   if not file_exist(mirror)  then mirror='mirror'
   mircmd=mirror + ' ' + pfile
   message,/info,"Spawning mirror cmd: " + mircmd
   if loud then spawn,mircmd else spawn,mircmd,result
endif  

if debug then stop
return
end
