pro ssw_index2map, index, data, maparr, noclobber=noclobber, $
                   soho=soho, sub=sub, ref_sub=ref_sub
;+
;   Name: ssw_index2map
;
;   Purpose: Make an image map (Zarro) from standard SSW structures
;
;   Input Parameters:
;      index - vector of 'index' structures (per mreadfits/fitshead2struct)
;      data  - 2D or 3D
;
;   Output Parameters:
;      maparr - 2D or 3D array of corresponding 'map structures'
;
;   Keyword Parameters:
;      soho - if set, force SOHO-view (default uses index.TELESCOP if present)
;      sub  - if switch, interactively select subfield
;             if 4 element vector, assume => [x1,x2,y1,y2] 
;
;   History:
;      14-Feb-1998 - S.L.Freeland, logic from D.M.Zarro FITS2MAP, GET_FITS_PAR
;-

;on_error,1
err=''

usesub=n_elements(sub) gt 0 or n_elements(sub_ref) gt 0  ; sub FOV?
if n_elements(sub_ref) eq 0 then sub_ref=0               ; default->1st 

stc=index                     ;
nimg=n_elements(stc)

; ----------- time --------------
time=anytim(index,/vms)

;-------- coordinates ------------
soho=keyword_set(soho) or $
     strpos(string(gt_tagval(stc,/telescop)),'SOHO') ne -1

dx=float(gt_tagval(stc,/cdelt1,found=found1))
dy=float(gt_tagval(stc,/cdelt2,found=found2))

if not (found1 and found2) then begin
   if tag_exist(stc,'radius') then begin
      h=pb0r(time,/arc,soho=soho) 
      dx=h(2)/stc.radius
      dy=dx
   endif else begin
      err='cannot determine image scale'
      message,err,/cont
      return
   endelse
endif

xcen=float((gt_tagval(stc,/naxis1))*dx)/2.
ycen=float((gt_tagval(stc,/naxis2))*dy)/2.
xorg=float((gt_tagval(stc,/crpix1))*dx)
yorg=float((gt_tagval(stc,/crpix2))*dy)

xp=xcen-xorg
yp=ycen-yorg
cv1=gt_tagval(stc,/crval1,found=found1)
cv2=gt_tagval(stc,/crval2,found=found2)
if found1 then xp=xp+cv1
if found2 then yp=yp+cv2

if err ne '' then return

if tag_exist(stc,'INSTRUME') then inst=strtrim(stc.instrume,2) else inst=''
if tag_exist(stc,'DETECTOR') then det=strtrim(stc.detector,2)  else det=''
if tag_exist(stc,'exptime') then dur=float(stc.exptime) else dur=0.
if total(dur) eq 0. then begin
 if tag_exist(stc,'date_obs') and tag_exist(stc,'date_end') then $
  dur=anytim2tai(stc.date_end)-anytim2tai(stc.date_obs)
endif

if tag_exist(stc,'telescop') then soho=(strpos(stc.telescop,'SOHO') gt -1) else soho=0
if tag_exist(stc,'wavelnth') then wave=strtrim(stc.wavelnth,2) else wave=''
if tag_exist(stc,'origin') then origin=strtrim(stc.origin,2) else origin=''

id=trim(inst+' '+det+' '+wave+' '+origin)

; -------- 
; ***** sub should be defined outside of this routine *******
if usesub and n_elements(sub) ne 4 then begin   ; interactive
   fdatai=data(*,*,sub_ref)
   exptv,fdatai
   wshow
   xloadct,/modal
   sub_data=tvsubimage(fdatai,x1,x2,y1,y2)
   sub=[x1,x2,y1,y2]
endif

;map=make_map(fdata,xcen,ycen,dx,dy,id=id,time=time,dur=dur,sub=sub,soho=soho)
;|-------- sample make_map call from fits2map ---------------------------|


; make the first map - use as template for 3D case
i=0
fdatai=data(*,*,i)

maparr=make_map(fdatai,xp(i),yp(i),dx(i),dy(i),$
      id=id(i),time=time(i),dur=dur(i),sub=sub,soho=soho(i))

for i=1,nimg-1 do begin                                    ; 3D loop
   fdatai=data(*,*,i)
    mapi=make_map(fdatai,xp(i),yp(i),dx(i),dy(i),$
        id=id(i),time=time(i),dur=dur(i),sub=sub,soho=soho(i))
    delvarx,fdatai
    maparr=str_concat(temporary(maparr),temporary(mapi))
endfor 

return

end
