;+
; Project     : SOHO - CDS
;
; Name        : FSTRING
;
; Purpose     : Shell around STRING function to fix 1024 size limit
;               on formatting strings
;
; Category    : Utility
;
; Explanation : 
;
; Syntax      : IDL> new=fstring(old,format=format)
;
; Inputs      : OLD = string to format
;
; Opt. Inputs : FORMAT = desired format
;
; Outputs     : NEW = new output string

; Opt. Outputs: None
;
; Keywords    : FORMAT = desired format (overides argument value)
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Version 1,  25-May-1997,  D.M. Zarro.  Written
;                           13-May-1998 (FZ)  Changed loop variables to long
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-

function fstring,input,format,format=key_format

if not exist(input) then return,''

if datatype(format) eq 'STR' then form=trim(format) else form=''
if datatype(key_format) eq 'STR' then form=trim(key_format)

if datatype(form) ne 'STR' then form=''
np=n_elements(input)
nmax=1024L
istart=0L
repeat begin
 iend=(istart+nmax-1L) < (np-1)
 chunk=string(input(istart:iend),form=form)
 if exist(new) then new=[new,chunk] else new=chunk
 istart=iend+1l
endrep until (iend eq (np-1))

if n_elements(new) eq 1 then new=new(0)
return,new & end

