;+
; Project     : SOHO - CDS
;
; Name        : GET_TAG_INDEX
;
; Purpose     : Return index of structure tag name
;
; Category    : Utility
;
; Explanation : Same as TAG_INDEX, except input can be both name or index
;               (If index, then check for validity)

;
; Syntax      : IDL> index=get_tag_index(stc,tag_name)
;
; Inputs      : STC = input structure
;               TAG_NAME = input tag name 
;
; Opt. Inputs : None
;
; Outputs     : INDEX = index location of named tag
;
; Opt. Outputs: None
;
; Keywords    : None
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Version 1,  23-Jan-1998,  D.M. Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-

function get_tag_index,stc,tag_name,err=err

err=''
if (datatype(stc) ne 'STC') or (not exist(tag_name)) then return,-1

tags=tag_names(stc)
ntags=n_elements(tags)

if datatype(tag_name) eq 'STR' then begin
 tag_no=tag_index(stc,tag_name)
endif else begin
 if (tag_name ge ntags) or (tag_name lt 0) then tag_no=-1 else tag_no=tag_name
endelse

if tag_no eq -1 then err='Invalid structure tag' 
return,tag_no

end

