;+
; Project     :	SDAC
;
; Name        :	JOIN_STRUCT
;
; Purpose     :	join two structures by appending tags
;
; Explanation :	
;
; Use         : NEW_STRUCT=JOIN_STRUCT(S1,S2)
;
; Inputs      :	S1,S2 input structures
;
; Opt. Inputs :	None.
;
; Outputs     :	NEW_STRUCT = new structure
;
; Opt. Outputs:	None.
;
; Keywords    :	NAME = new name for structure
;               DUPLICATE = keep duplicate tag names
;
; Calls       :	ADD_TAG
;
; Common      :	None.
;
; Restrictions:	Input structures must have same dimension
;
; Side effects:	None.
;
; Category    :	Structure handling
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (ARC), 7 November 1994
;               Modified, 9 April 1997, Zarro (ARC), added DUPLICATE
;               Modified, 19 Sept 1997, Zarro (SAC), replaced CREATE_STRUCT
;               call by ADD_TAG
;
; Version     :	Version 3



function join_struct,s1,s2,name=name,duplicate=duplicate

on_error,1

no_dup=1-keyword_set(duplicate)

eflag=0
if datatype(s2) ne 'STC' then eflag=1
if (n_elements(s1) ne 0) and $
   ((datatype(s1) ne 'STC') and (datatype(s2) ne 'STC')) then eflag=1

if eflag then begin
 pr_syntax,'new_struct=join_struct(s1,s2,name=name)'
 return,0
endif

if (n_elements(s1) ne 0) and (n_elements(s1) ne n_elements(s2)) then begin
 message,'input structures must have same dimensions',/cont
 return,0
endif

nstruct=n_elements(s1)
tags=tag_names(s2)
ntags=n_elements(tags)

if nstruct eq 0 then new_struct=s2 else begin
 for k=0,nstruct-1 do begin
  temp_struct=s1(k)
  for j=0,ntags-1 do temp_struct=add_tag(temp_struct,s2(k).(j),tags(j),duplicate=duplicate)
  new_struct=merge_struct(new_struct,temp_struct)
 endfor
endelse

new_struct=rep_struct_name(new_struct,name)

return,new_struct & end

