;+
; Project     :	SOHO - CDS
;
; Name        :	MERGE_STRUCT
;
; Purpose     :	merge/concatanate two structures
;
; Explanation :	concatanates two structures by using CREATE_STRUCT to
;               ensure that input structures have the same name and, thus, 
;               avoid the problem of concatanating two differently named
;               structures.
;
; Use         : NEW_STRUCT=MERGE_STRUCT(STRUCT1,STRUCT2)
;
; Inputs      :	STRUCT1,2 = input structures
;
; Opt. Inputs :	None.
;
; Outputs     :	NEW_STRUCT = concatanated structure
;
; Opt. Outputs:	None.
;
; Keywords    :	ERR = err string
;               NOTAG_CHECK = don't check if tag names match.
;
; Calls       :	COPY_STRUCT
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Structure handling
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (SAC/GSFC)
;
; Version     :	Version 1.0, 19 January 1998
;-

function merge_struct,struct1,struct2,err=err,notag_check=notag_check

err=''
if (datatype(struct1) ne 'STC') or (datatype(struct2) ne 'STC')  then begin
 if (datatype(struct1) eq 'STC') then return,struct1
 if (datatype(struct2) eq 'STC') then return,struct2
 err='invalid input structures'
 message,err,/cont
 return,0
endif

s1=tag_names(struct1,/struct)
s2=tag_names(struct2,/struct)

if (1-keyword_set(notag_check)) then begin
 smatch=match_struct(struct1,struct2,/tags) 
 if not smatch then begin
  err='Input structures do not have matching tag names'
  message,err,/cont
  return,struct1
 endif
endif

if (s1 eq s2) and (s1 ne '') then return,[struct1,struct2]

case 1 of
 (s1 eq '') and (s2 ne ''): begin
   name=s2
   for i=0,n_elements(struct1)-1 do begin
    temp=create_struct(struct1(i),name=s2)
    if i eq 0 then new=temp else new=[temp,temporary(new)]
   endfor
   return,[temporary(new),struct2]
  end
 (s2 eq '') and (s1 ne ''): begin
   name=s1
   for i=0,n_elements(struct2)-1 do begin
    temp=create_struct(struct2(i),name=s1)
    if i eq 0 then new=temp else new=[temp,temporary(new)]
   endfor
   return,[struct1,temporary(new)]
  end
 else: begin
  sname=make_str(1,/noexe)
  for i=0,n_elements(struct1)-1 do begin
   temp=create_struct(struct1(i),name=sname)
   if i eq 0 then new1=temp else new1=[temp,temporary(new1)]
  endfor
  for i=0,n_elements(struct2)-1 do begin
   temp=create_struct(struct2(i),name=sname)
   if i eq 0 then new2=temp else new2=[temp,temporary(new2)]
  endfor
  return,[temporary(new1),temporary(new2)]
 end
endcase

end
