;+
; Project     :	SDAC
;
; Name        :	REM_DUP_TAG
;
; Purpose     :	remove duplicate tags from a structure
;
; Explanation :	
;
; Use         : NEW_STRUCT=REM_DUP_TAG(STRUCT)
;
; Inputs      :	STRUCT = input structure (array or scalar)
;
; Opt. Inputs :	None.
;
; Outputs     :	NEW_STRUCT = new structure
;
; Opt. Outputs:	None.
;
; Keywords    :	NAME = new name for output structure
;
; Calls       :	CONCAT_STRUCT
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Structure handling
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (ARC), April 7, 1997
;		Version 1.1: Fixed vectorization bug. Craig DeForest (Stanford), May 13, 1997
;
; Version     :	Version 1.1
;-

function rem_dup_tag,struct,name=name

if (datatype(struct) ne 'STC') then begin
 message,'syntax --> NEW_STRUCT=REM_DUP_TAG(STRUCT)',/cont
 if exist(struct) then return,struct else return,0
endif

;-- any duplicates?

tags=tag_names(struct)
rs=uniq([tags],sort([tags]))
utags=tags(rs) 

if n_elements(utags) eq n_elements(tags) then return,struct

;-- now strip
 
ntags=n_elements(tags)
for k=0,n_elements(struct)-1 do begin
 delvarx,temp_struct
 for i=0,ntags-1 do begin
  tlook=where(tags(i) eq tags,count)
  keep=struct(k).(tlook(0))
  if exist(temp_struct) then $
   temp_struct=add_tag(temporary(temp_struct),keep,tags(i)) else $
    temp_struct=add_tag(temp_struct,keep,tags(i))
 endfor
 if not exist(new_struct) then new_struct=temporary(temp_struct) else $
  new_struct=merge_struct(temporary(new_struct),temporary(temp_struct))
endfor

new_struct=rep_struct_name(temporary(new_struct),name)

return,new_struct & end




