;+
; Project     :	SDAC
;
; Name        :	REM_TAG
;
; Purpose     :	remove a tag from a structure
;
; Explanation :	
;
; Use         : NEW_STRUCT=REM_TAG(STRUCT,TAG)
;
; Inputs      :	STRUCT = input structure (array or scalar)
;             : TAG = array of tag names to remove
;
; Opt. Inputs :	None.
;
; Outputs     :	NEW_STRUCT = new structure
;
; Opt. Outputs:	None.
;
; Keywords    :	NAME = new name for output structure
;
; Calls       :	CONCAT_STRUCT
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Structure handling
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (ARC)
;
; Modified    : Version 2, S.V.H. Haugan (UiO), 13 June 1996
;                       Stopped using undocumented REMOVE keyword that
;                       tripped an internal bug in normal create_struct
;                       calls.
;               Version 3, Zarro (GSFC) 16 June 1996 -- cleaned up
;
; Version     :	Version 3, 16 June 1996
;-


function rem_tag,struct,tag_name,name=name

if (datatype(struct) ne 'STC') then begin
 message,'syntax --> NEW_STRUCT=REM_TAG(STRUCT,TAG_NAME)',/cont
 if exist(struct) then return,struct else return,0
endif

;-- find indicies of tags to remove

if not exist(tag_name) then return,struct
new_struct=0
tags=tag_names(struct) & ntag=n_elements(tags)
if datatype(tag_name) eq 'STR' then begin
 tag_index=where_vector(tag_name,tags,count,/trim)
 if count eq 0 then return,struct
endif else begin
 ok=where( (tag_name lt ntag) and (tag_name ge 0),cnt)
 if cnt eq 0 then return,struct
 tag_index=tag_name(ok)
 tag=tags(tag_name(ok))
endelse

if n_elements(tag_index) eq n_elements(tags) then return,-1

nstruct=n_elements(struct)
for k=0,nstruct-1 do begin
 for i=0,n_elements(tags)-1 do begin
  if total(i eq [tag_index]) eq 0 then begin
   temp_struct=add_tag(temp_struct,struct(k).(i),tags(i)) 
  endif
 endfor
 if exist(new_struct) then $
  new_struct=merge_struct(temporary(new_struct),temporary(temp_struct)) else $
   new_struct=temporary(temp_struct)
endfor

new_struct=rep_struct_name(temporary(new_struct),name)

return,new_struct & end


