;+
; Project     :	SDAC
;
; Name        :	REP_STRUCT_NAME
;
; Purpose     :	Replace structure name 
;
; Explanation :	
;
; Use         : NEW_STRUCT=REP_STRUCT_NAME(STRUCT,NEW_NAME)
;
; Inputs      :	STRUCT = input structure
;             : NEW_NAME= new structure name
;
; Opt. Inputs :	None.
;
; Outputs     :	NEW_STRUCT = new structure
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Structure handling
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (ARC)
;
; Version     :	Version 1.0, 7 July 1995
;-


function rep_struct_name,struct,new_name

if (datatype(struct) ne 'STC') then begin
 message,'syntax --> NEW_STRUCT=REP_STRUCT_NAME(STRUCT,NEW_NAME)',/cont
 if exist(struct) then return,struct else return,0
endif

new_ver=float(strmid(!version.release,0,3)) ge 3.6
if (datatype(new_name) ne 'STR') or (not new_ver) then return,struct

;-- check if same name

cur_name=strupcase(trim(tag_names(struct,/struct)))
if datatype(new_name) ne 'STR' then sname='' else sname=new_name
sname=trim(strupcase(sname))
if cur_name eq new_name then return,struct

;-- check if new name is unique

status=1
if sname ne '' then status=chk_struct_name(sname,temp=temp)

if (not status) and datatype(temp) eq 'STC' and (sname ne '') then begin
 if not match_struct(struct,temp,/type) then begin
  message,'Structure type already defined: '+new_name,/cont
  return,struct
 endif
endif

;-- have to loop because CREATE_STRUCT doesn't take vectors

for i=0,n_elements(struct)-1 do begin
 temp_struct=create_struct(struct(i),name=sname)
 if exist(new_struct) then $
  new_struct=merge_struct(temporary(new_struct),temporary(temp_struct)) else $
   new_struct=temporary(temp_struct)
endfor

return,new_struct

end

