;+
; Project     :	SDAC
;
; Name        :	REP_TAG_NAME
;
; Purpose     :	Replace a tag name in structure
;
; Explanation :	
;
; Use         : NEW_STRUCT=REP_TAG_NAME(STRUCT,OLD_NAME,NEW_NAME)
;
; Inputs      :	STRUCT = input structure
;             : OLD_NAME = old tag name or index
;             : NEW_NAME= new tag name
;
; Opt. Inputs :	None.
;
; Outputs     :	NEW_STRUCT = new structure
;
; Opt. Outputs:	None.
;
; Keywords    :	NAME = new name for output structure
;               RECURSE = search and replace recursively
;
; Calls       :	CONCAT_STRUCT
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Structure handling
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (ARC)
;
; Version     :	Version 1.0, 7 November 1994
;               Version 2.0, 23 March 1998 -- added nested search
;-


function rep_tag_name,struct,old_name,new_name,name=name,err=err,$
                      quiet=quiet,recurse=recurse

on_error,1
err=''

recurse=keyword_set(recurse)
verbose=1-keyword_set(quiet)
if (datatype(struct) ne 'STC') or $
   (datatype(new_name) ne 'STR') then begin
 pr_syntax,'new_struct=rep_tag_name(struct,old_name,new_name)'
 return,0
endif

if n_elements(old_name) ne 1 then begin
 message,'restricted to replacing one tag at a time',/cont
 if exist(struct) then return,struct else return,0
endif

;-- do a recursive search for tag name

tags=tag_names(struct) & ntags=n_elements(tags)
if datatype(old_name) eq 'STR' then begin
 clook=where(tags eq strupcase(old_name),cnt)
 if cnt eq 0 then begin
  if recurse then begin
   for k=0,ntags-1 do begin
    if datatype(struct.(k)) eq 'STC' then begin
     tstruct=rep_tag_name(struct.(k),old_name,new_name,err=err,/quiet)
     if err eq '' then begin
      new_struct=rep_tag_value(struct,tstruct,tags(k),name=name)
      return,new_struct
     endif
    endif
   endfor
  endif
  err='tag name < '+old_name+' > not found'
  if verbose then message,err,/cont
  if exist(struct) then return,struct else return,0
 endif
endif else begin
 clook=old_name 
 if (clook lt 0) or (clook gt (ntags-1)) then begin
  err='index out of range'
  if verbose then message,err
  if exist(struct) then return,struct else return,0
 endif
endelse

if trim(strupcase(old_name)) eq trim(strupcase(new_name)) then return,struct

tag_index=clook(0)
for k=0,n_elements(struct)-1 do begin
 tag_value=struct(k).(tag_index)
 temp_struct=rem_tag(struct(k),old_name)
 err=''
 temp_struct=add_tag(temporary(temp_struct),tag_value,new_name,index=tag_index-1,err=err)
 if err ne '' then temp_struct=struct(k)
 if not exist(new_struct) then new_struct=temporary(temp_struct) else $
  new_struct=merge_struct(temporary(new_struct),temporary(temp_struct))
endfor

new_struct=rep_struct_name(temporary(new_struct),name)

return,new_struct & end


