;+
; Project     : SOHO - CDS
;
; Name        :
;	CHKLOG
; Purpose     :
;	Determine actual name of logical or environment variable.
; Explanation :
;	This routine determines the actual name of a logical name (VMS) or
;	environment variable (UNIX).  In VMS the routine TRNLOG,/FULL is used;
;	otherwise GETENV is used.
; Use         :
;	Result = CHKLOG( VAR  [, OS ] )
; Inputs      :
;	VAR = String containing the name of the variable to be translated.
; Opt. Inputs :
;	None.
; Outputs     :
;	The result of the function is the translated name, or (in VMS) an array
;	containing the translated names.
; Opt. Outputs:
;       OS = The name of the operating system, from !VERSION.OS.
; Keywords    :
;	None.
; Calls       :
;	None.
; Common      :
;	None.
; Restrictions:
;	None.
; Side effects:
;	None.
; Category    :
;	Utilities, Operating_system.
; Prev. Hist. :
;       Written  - DMZ (ARC) May 1991
;       Modified - DMZ (ARC) Nov 1992, to use GETENV
; Written     :
;	D. Zarro, GSFC/SDAC, May 1991.
; Modified    :
;	Version 1, William Thompson, GSFC, 23 April 1993.
;		Incorporated into CDS library.
;       Version 2, Dominic Zarro, GSFC, 1 August 1994.
;               Added capability for vector inputs
;       Version 3, Liyun Wang, GSFC/ARC, January 3, 1995
;               Added capability of interpreting the "~" character under UNIX
;       Version 4, Zarro, GSFC/ARC, February 17 1997
;               Added call to EXPAND_TILDE, corrected many potential bugs
;
; VERSION:
;       Version 4.
;-
;

   function chklog,var,os

   if datatype(var) ne 'STR' then begin
    message,'invalid input',/contin
    if exist(var) then return,var else return,''
   endif

   os=os_family()
   for i=0,n_elements(var)-1 do begin
    svar=var(i)
    if os eq 'vms' then begin
     colon=strpos(svar,':')
     if colon eq (strlen(svar)-1) then $
      tvar=strmid(svar,0,strlen(svar)-1) else tvar=svar
     s=execute('v=trnlog(tvar,name,/full)')
     if (v mod 2) eq 0 then name=''
    endif else begin
     tilde=strpos(svar,'~')
     if tilde gt -1 then begin
      name=svar
      status=execute('name=expand_tilde(svar)')
     endif else begin
      doll=strpos(svar,'$')
      if doll eq 0 then begin
       tvar=strmid(svar,1,1000) 
       slash=strpos(tvar,'/')
       if slash eq (strlen(tvar)-1) then tvar=strmid(tvar,0,strlen(tvar)-1)
      endif else tvar=svar
      name=getenv(tvar)
     endelse
    endelse
    if i eq 0 then rvar = name else rvar = [rvar,name]
   endfor
   if n_elements(rvar) eq 1 then rvar = rvar(0)
   if datatype(rvar) eq 'STR' then rvar=trim(rvar)
   return, rvar
   end
