;+
; Project     : SOHO - CDS
;
; Name        : KILL_JOB
;
; Purpose     : Kill a UNIX job
;
; Category    : Utility
;
; Explanation : e.g. kill_job,'telnet' to kill all jobs with the containing
;               the string 'telnet'
;
; Syntax      : IDL> kill_job,job_name
;
; Inputs      : JOB_NAME = name of job to kill
;
; Opt. Inputs : None
;
; Outputs     : None
;
; Opt. Outputs: None
;
; Keywords    : /CASE: job searching is case sensitive
;               /EXACT: job name must be exact
;               /REPORT: report but don't kill jobs
;               /VERBOSE: send messages
;
; Common      : None
;
; Restrictions: UNIX only
;
; Side effects: None
;
; History     : Version 1,  5-Dec-1997,  D.M. Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-


pro kill_job,job,_extra=extra,verbose=verbose,report=report

if strupcase(os_family()) ne 'UNIX' then return

verbose=keyword_set(verbose)
if datatype(job) ne 'STR' then return
espawn,'ps -ae',out,count=count
jobs=grep(job,out,_extra=extra)
if out(0) eq '' then begin
 message,job+ 'not found',/count
 return
endif

njobs=n_elements(jobs)
for i=0,njobs-1 do begin
 if keyword_set(report) then begin
  if i eq 0 then message,'following job(s) will be killed',/cont 
  print,jobs(i)
 endif else begin
  proc=str2arr(trim(jobs(i)),delim=' ')
  job_id=proc(0)
  if job_id ne '' then begin
   state='kill -9 '+job_id
   espawn,state,out
   if verbose and trim(out(0)) ne '' then message,out(0),/cont
  endif
 endelse
endfor

return & end
