;+
; Project     : SOHO - CDS
;
; Name        : LIST_PRINTER_UNIX
;
; Purpose     : LIST available printers from /etc/printcap
;
; Category    : Help, Device
;
; Explanation : Reads /etc/printcap 
;
; Syntax      : IDL> printers=list_printer_unix(desc)
;
; Examples    :
;
; Inputs      : None
;
; Opt. Inputs : None
;
; Outputs     : PRINTERS - printer que names
;
; Opt. Outputs: DESC -  description of each printer
;
; Keywords    : ERR - error messages
;
; Common      : LIST_PRINTER_UNIX - contains last reading of printcap file
;
; Restrictions: Unix only.
;
; Side effects: None
;
; History     : Version 1,  8-Aug-1995, D M Zarro . Written
;               Version 2,  1 July 1996, S.V.H.Haugan (UiO)
;                       Added PSLASER/PSCOLOR/PSCOLOR2 environmentals check.
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-

function list_printer_unix,desc,err=err

common list_printer_unix,printers_com,desc_com

printers=''
err=''
desc=''

if exist(printers_com) then begin
 printers=printers_com
 if exist(desc_com) then desc=desc_com
 return,printers
endif

printcap='/etc/printcap'           ;-- sorry Unix only
clook=loc_file(printcap,count=nf)  ;-- look for printcap file
def_printers=[getenv("PRINTER"),getenv("PSLASER"), $
              getenv("PSCOLOR"),getenv("PSCOLOR2")]
def_desc=['PRINTER','PSLASER','PSCOLOR','PSCOLOR2']

if nf eq 0 then begin
 err='Cannot determine printers, trying PRINTER/PSLASER/PSCOLOR environmentals'
 message,err,/cont
 printers=def_printers
 desc = def_desc
 ix = where(printers  ne '',count)
 if count eq 0 then begin
  printers = ''
  desc = ''
 end else begin
  printers = printers(ix)
  desc = desc(ix)
 end
endif else begin

;-- read and parse printcap file

 file=rd_ascii(printcap)
 vert=strpos(file,'|')
 ok=where(vert gt -1,count)
 if count gt 0 then begin
  printers=strarr(count) & desc=printers
  temp=file(ok) & vert=vert(ok)
  for i=0,count-1 do begin
   tp=strmid(temp(i),0,vert(i))
   printers(i)=tp
   colon=strpos(temp(i),':')
   if colon gt -1 then begin
    sub= string(reverse(byte(strmid(temp(i),0,colon))))
    vert2=strpos(sub,'|')
    if vert2 gt 0 then begin
     sub2=string(reverse(byte(strmid(sub,0,vert2))))
     desc(i)=sub2
    endif
   endif  
  endfor
 endif

 desc=trim(desc)
 printers=trim(printers)
 for i=0,n_elements(def_printers)-1 do begin
  chk=where(strupcase(def_printers(i)) eq strupcase(printers),cnt)
  if cnt gt 0 then begin
   desc(chk(0))=desc(chk(0))+' ('+def_desc(i)+')'
  endif
 endfor
endelse

if printers(0) ne '' then begin
 printers_com=printers
 desc_com=desc
endif

return,printers
end 


