;+
; Project     : SOHO - CDS
;
; Name        : RD_LINK
;
; Purpose     : check if file name is actually a link
;
; Category    : Help
;
; Explanation : spawns  'ls -l' to check for links
;
; Syntax      : IDL> link = rd_link(file)
;
; Inputs      : FILE = string file name
;
; Opt. Inputs : None
;
; Outputs     : LINK =  filename to which FILE is linked
;
; Opt. Outputs: None
;
; Keywords    : STATUS=1 if actually a link, 0 otherwise
;
; Common      : None
;
; Restrictions: UNIX only
;
; Side effects: None
;
; History     : Version 1,  1-June-1996,  D.M. Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-


function rd_link,file,status=status

on_error,1
cnt=0
status=0
vms=os_family() eq 'vms'
lfile=''
if datatype(file) ne 'STR' then return,lfile

lfile=file
if n_elements(file) ne 1 then begin
 message,'single filenames only',/cont
 return,lfile
endif

if vms then return,lfile

espawn,'\ls -l '+file,out
arrows=strpos(out,'->')
links=where(arrows gt -1,cnt)
if cnt gt 0 then begin
 out=out(links) & arrows=arrows(links)
 lfile=strarr(cnt)
 for i=0,cnt-1 do lfile(i)=strmid(out(i),arrows(i)+2,strlen(out(i)))
 status=1
 lfile=trim(lfile)
endif

if n_elements(lfile) eq 1 then lfile=lfile(0)

return,lfile & end


