;+
; Project     : SOHO-CDS
;
; Name        : TEST_DIR
;
; Purpose     : Test that a directory exists and is writable
;
; Category    : Utility
;
; Explanation :
;
; Syntax      : status=test_dir(dir_name)
;
; Examples    :
;
; Inputs      : DIR_NAME = directory name to check
;
; Opt. Inputs : None
;
; Outputs     : status = 1/0 if exists/not
;
; Opt. Outputs: 
;
; Keywords    : ERR = output messages
;               QUIET = turn off printing output messages
;
; Common      : None
;
; Restrictions: Unix only 
;
; Side effects: None
;
; History     : Written 14 May 1998 D. Zarro, SAC/GSFC
;
; Contact     : dzarro@solar.stanford.edu
;-

function test_dir,dir_name,quiet=quiet,err=err

err=''
status=0b
if datatype(dir_name) ne 'STR' then begin
 err='Invalid directory name'
 pr_syntax,'chk=test_dir(dir_name)'
 return,status
endif
if dir_name eq '' then return,1b

loud=1-keyword_set(quiet)
chk_loc=loc_file(dir_name,err=err,verbose=loud,count=fcount)
if fcount eq 0 then return,status
dir_name=chk_loc(0)

if not chk_dir(dir_name) then begin
 err=dir_name+' is not a valid directory'
 if loud then message,err,/cont
 return,status
endif

chk_write=test_open(dir_name,/write,quiet=quiet,err=err)
if not chk_write then return,status

return,1b & end
